#pragma once
#include <iostream>
#include <sstream>
#include <boost/uuid/uuid.hpp>
#include <boost/uuid/uuid_io.hpp>
#include <set>

namespace spin
{
    struct Group
    {
        Group(const std::string &name, const boost::uuids::uuid &uuid, const std::set<boost::uuids::uuid> &programs)
            : name_(name), uuid_(uuid), programUuids(programs)
        {
        }

        inline friend std::ostream &operator<<(std::ostream &out, const Group &group)
        {
            out << "name: " << group.name_ << std::endl;
            out << "uuid: " << group.uuid_ << std::endl;
            out << "programs: " << std::endl;
            for (auto program : group.programUuids)
            {
                out << "  " << program << std::endl;
            }
            return out;
        }

        std::string toString() const
        {
            std::ostringstream oss;
            oss << *this;
            return oss.str();
        }

        inline bool operator<(const Group &rhs) const
        {
            return name_ < rhs.name_;
        }

        std::string name_;
        boost::uuids::uuid uuid_;
        std::set<boost::uuids::uuid> programUuids;
    };

} // namespace spin
