#pragma once
#include <boost/uuid/uuid.hpp>
#include <boost/uuid/uuid_generators.hpp>
#include <boost/uuid/uuid_io.hpp>

namespace spin
{
    struct ProgramResult
    {
        enum Evaluation
        {
            FAULT,
            NOT_OK,
            OK
        };

        ProgramResult(const boost::uuids::uuid &uuid,
                      const std::time_t &time,
                      const Evaluation &evaluation) : uuid_(uuid),
                                                      time_(time),
                                                      evaluation_(evaluation)
        {
            // TODO
            // finalInsertionDepth
            // finalTorque
            // goalMax
            // goalMin
            // goalValue
            // positionTrace
            // screwProgramId
            // timestamp
            // torqueTrace

        }

        inline friend std::ostream &operator<<(std::ostream &out, const ProgramResult &programResult)
        {
            out << "time: " << programResult.time_ << std::endl;
            out << "uuid: " << programResult.uuid_ << std::endl;

            switch (programResult.evaluation_)
            {
            case Evaluation::FAULT:
                out << "evaluation: FAULT" << std::endl;
                break;
            case Evaluation::NOT_OK:
                out << "evaluation: NOT_OK" << std::endl;
                break;
            case Evaluation::OK:
                out << "evaluation: OK" << std::endl;
                break;
            default:
                out << "evaluation: UNKNOWN" << std::endl;
                break;
            }

            return out;
        }

        std::string toString() const
        {
            std::ostringstream oss;
            oss << *this;
            return oss.str();
        }

        boost::uuids::uuid uuid_;
        std::time_t time_;
        Evaluation evaluation_;
        // Length  finalInsertionDepth_;
        // Torque  finalTorque_;
        // ProgramGoal goal_;
        // DataTrace insertionDepthTrace_;
        // DataTrace toolTorqueTrace_;
    };
} // namespace spin